@@ -1,5 +1,21 @@
+begin
+  require 'active_support/ordered_hash'
+rescue LoadError
+  require 'extlib/dictionary'
+  module ActiveSupport
+    OrderedHash = Dictionary unless defined?(OrderedHash)
+  end
+end
+
+require 'dm-core'
+
 module DataMapper
   module Serialize
+
+    def self.dm_validations_loaded?
+      DataMapper.const_defined?("Validations")
+    end
+
     # Returns propreties to serialize based on :only or :exclude arrays, if provided
     # :only takes precendence over :exclude
     #
@@ -17,12 +33,6 @@ module DataMapper
       end
     end
 
-    Model.append_inclusions self
-
-    class Support
-      def self.dm_validations_loaded?
-        DataMapper.const_defined?("Validate")
-      end
-    end
   end
+  Model.append_inclusions(Serialize)
 end
