@@ -20,27 +20,14 @@ module DataMapper
     def to_csv(writer = '')
       CSV.generate(writer) do |csv|
         row = model.properties(repository.name).map do |property|
-          send(property.name).to_s
+          __send__(property.name).to_s
         end
         csv << row
       end
     end
-  end
 
-  class Collection
-    def to_csv
-      result = ''
-      each do |item|
-        result << item.to_csv + "\n"
-      end
-      result
-    end
-  end
-
-  if Serialize::Support.dm_validations_loaded?
-
-    module Validate
-      class ValidationErrors
+    module ValidationErrors
+      module ToCsv
         def to_csv(writer = '')
           CSV.generate(writer) do |csv|
             errors.each do |key, value|
@@ -55,6 +42,25 @@ module DataMapper
         end
       end
     end
+  end
+
+  class Collection
+    def to_csv
+      result = ''
+      each do |item|
+        result << item.to_csv + "\n"
+      end
+      result
+    end
+  end
+
+  if Serialize.dm_validations_loaded?
+
+    module Validations
+      class ValidationErrors
+        include DataMapper::Serialize::ValidationErrors::ToCsv
+      end
+    end
 
   end
 
