@@ -12,7 +12,6 @@ module DataMapper
       xml.output(to_xml_document(opts)).to_s
     end
 
-    protected
     # This method requires certain methods to be implemented in the individual
     # serializer library subclasses:
     # new_document
@@ -22,21 +21,21 @@ module DataMapper
     def to_xml_document(opts={}, doc = nil)
       xml = XMLSerializers::SERIALIZER
       doc ||= xml.new_document
-      default_xml_element_name = lambda { Extlib::Inflection.underscore(model.name).tr("/", "-") }
+      default_xml_element_name = lambda { DataMapper::Inflector.underscore(model.name).tr("/", "-") }
       root = xml.root_node(doc, opts[:element_name] || default_xml_element_name[])
       properties_to_serialize(opts).each do |property|
-        value = send(property.name)
-        attrs = (property.type == String) ? {} : {'type' => property.type.to_s.downcase}
+        value = __send__(property.name)
+        attrs = (property.primitive == String) ? {} : {'type' => property.primitive.to_s.downcase}
         xml.add_node(root, property.name.to_s, value, attrs)
       end
 
       (opts[:methods] || []).each do |meth|
         if self.respond_to?(meth)
           xml_name = meth.to_s.gsub(/[^a-z0-9_]/, '')
-          value = send(meth)
+          value = __send__(meth)
           unless value.nil?
             if value.respond_to?(:to_xml_document)
-              xml.add_xml(root, value.send(:to_xml_document))
+              xml.add_xml(root, value.to_xml_document)
             else
               xml.add_node(root, xml_name, value.to_s)
             end
@@ -45,37 +44,13 @@ module DataMapper
       end
       doc
     end
-  end
 
-  class Collection
-    def to_xml(opts = {})
-      to_xml_document(opts).to_s
-    end
-
-    protected
-
-    def to_xml_document(opts = {})
-      xml = DataMapper::Serialize::XMLSerializers::SERIALIZER
-      doc = xml.new_document
-      default_collection_element_name = lambda {Extlib::Inflection.pluralize(Extlib::Inflection.underscore(self.model.to_s)).tr("/", "-")}
-      root = xml.root_node(doc, opts[:collection_element_name] || default_collection_element_name[], {'type' => 'array'})
-      self.each do |item|
-        item.send(:to_xml_document, opts, doc)
-      end
-      doc
-    end
-  end
-
-  if Serialize::Support.dm_validations_loaded?
-
-    module Validate
-      class ValidationErrors
+    module ValidationErrors
+      module ToXml
         def to_xml(opts = {})
           to_xml_document(opts).to_s
         end
 
-        protected
-
         def to_xml_document(opts = {})
           xml = DataMapper::Serialize::XMLSerializers::SERIALIZER
           doc = xml.new_document
@@ -95,4 +70,31 @@ module DataMapper
     end
 
   end
+
+  class Collection
+    def to_xml(opts = {})
+      to_xml_document(opts).to_s
+    end
+
+    def to_xml_document(opts = {})
+      xml = DataMapper::Serialize::XMLSerializers::SERIALIZER
+      doc = xml.new_document
+      default_collection_element_name = lambda {DataMapper::Inflector.pluralize(DataMapper::Inflector.underscore(self.model.to_s)).tr("/", "-")}
+      root = xml.root_node(doc, opts[:collection_element_name] || default_collection_element_name[], {'type' => 'array'})
+      self.each do |item|
+        item.to_xml_document(opts, doc)
+      end
+      doc
+    end
+  end
+
+  if Serialize.dm_validations_loaded?
+
+    module Validations
+      class ValidationErrors
+        include DataMapper::Serialize::ValidationErrors::ToXml
+      end
+    end
+
+  end
 end
