@@ -1,5 +1,3 @@
-require 'spec_helper'
-
 share_examples_for 'A serialization method that also serializes core classes' do
   # This spec ensures that we don't break any serialization methods attached
   # to core classes, such as Array
@@ -12,9 +10,7 @@ share_examples_for 'A serialization method that also serializes core classes' do
   end
 
   before(:each) do
-    Cow.all.destroy!
-    Planet.all.destroy!
-    FriendedPlanet.all.destroy!
+    DataMapper::Model.descendants.each { |model| model.destroy! }
   end
 
   it 'serializes an array of extended objects' do
@@ -57,9 +53,7 @@ share_examples_for 'A serialization method' do
   end
 
   before(:each) do
-    Cow.all.destroy!
-    Planet.all.destroy!
-    FriendedPlanet.all.destroy!
+    DataMapper::Model.descendants.each { |model| model.destroy! }
   end
 
   describe '(serializing single resources)' do
@@ -238,18 +232,27 @@ share_examples_for 'A serialization method' do
     end
   end
 
-  describe "(multiple repositories)" do
-    before(:all) do
-      QuanTum::Cat.auto_migrate!
-      DataMapper.repository(:alternate) { QuanTum::Cat.auto_migrate! }
+  with_alternate_adapter do
+
+    describe "(multiple repositories)" do
+      before(:all) do
+        [ :default, :alternate ].each do |repository_name|
+          DataMapper.repository(repository_name) do
+            QuanTum::Cat.auto_migrate!
+            QuanTum::Cat.destroy!
+          end
+        end
+      end
+
+      it "should use the repsoitory for the model" do
+        alternate_repo = DataMapper::Spec.spec_adapters[:alternate].name
+        gerry = QuanTum::Cat.create(:name => "gerry")
+        george = DataMapper.repository(alternate_repo){ QuanTum::Cat.create(:name => "george", :is_dead => false) }
+        @harness.test(gerry )['is_dead'].should be(nil)
+        @harness.test(george)['is_dead'].should be(false)
+      end
     end
 
-    it "should use the repsoitory for the model" do
-      gerry = QuanTum::Cat.create(:name => "gerry")
-      george = DataMapper.repository(:alternate){ QuanTum::Cat.create(:name => "george", :is_dead => false) }
-      @harness.test(gerry )['is_dead'].should be(nil)
-      @harness.test(george)['is_dead'].should be(false)
-    end
   end
 
   it 'should integrate with dm-validations' do
